hpf
Add DCT bases to nuisance to apply a temporal high-pass
filter to the data, for detrending? hpf is the filter frequency.
Use NULL to skip detrending. Detrending is strongly recommended for
fMRI data, to help reduce the autocorrelation in the residuals, so
NULL will induce a warning. Use "already" to disable the
warning while skipping highpass filtering.
Using at least two DCT bases is as sufficient for detrending as using linear
and quadratic drift terms in the nuisance matrix. So if DCT detrending is
being used here, there is no need to add linear and quadratic drift terms to
nuisance.